Module css

Module css 

CSS

Bubba supports real .css files. At build time, cargo bubba build bundles all referenced CSS into the APK’s assets folder. At runtime, the CSS parser resolves class names to style properties and passes them to the native renderer.

Example

/* assets/main.css */
.title       { font-size: 24px; font-weight: bold; color: #1a1a2e; }
.primary-btn { background: #4CAF50; color: white; border-radius: 8px; }
.danger-btn  { background: #e53935; color: white; }
.avatar      { width: 80px; height: 80px; border-radius: 40px; }

Structs

StyleSheet
A parsed CSS stylesheet.

Constants

MAIN_CSS_EXAMPLE
Bundled CSS string — embedded at compile time.